<a id="mypy-boto3-config"></a>

# mypy-boto3-config

[![PyPI - types-aiobotocore-config](https://img.shields.io/pypi/v/types-aiobotocore-config.svg?color=blue)](https://pypi.org/project/types-aiobotocore-config)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-config.svg?color=blue)](https://pypi.org/project/types-aiobotocore-config)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-config?color=blue)](https://pypistats.org/packages/types-aiobotocore-config)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.ConfigService 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/config.html#ConfigService)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-config docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_config/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-config](#mypy-boto3-config)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `ConfigService`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `ConfigService` service.

```bash
python -m pip install types-aiobotocore[config]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[config]` in your environment:
  `python -m pip install 'types-aiobotocore[config]'`

Both type checking and auto-complete should work for `ConfigService` service.
No explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[config]` in your environment:
  `python -m pip install 'types-aiobotocore[config]'`

Both type checking and auto-complete should work for `ConfigService` service.
No explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[config]` in your environment:
  `python -m pip install 'types-aiobotocore[config]'`
- Run `mypy` as usual

Type checking should work for `ConfigService` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[config]` in your environment:
  `python -m pip install 'types-aiobotocore[config]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ConfigService` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ConfigServiceClient` provides annotations for
`session.create_client("config")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_config import ConfigServiceClient

session = get_session()
with async session.create_client("config") as client:
    client: ConfigServiceClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_config.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_config import ConfigServiceClient
from types_aiobotocore_config.paginator import (
    DescribeAggregateComplianceByConfigRulesPaginator,
    DescribeAggregateComplianceByConformancePacksPaginator,
    DescribeAggregationAuthorizationsPaginator,
    DescribeComplianceByConfigRulePaginator,
    DescribeComplianceByResourcePaginator,
    DescribeConfigRuleEvaluationStatusPaginator,
    DescribeConfigRulesPaginator,
    DescribeConfigurationAggregatorSourcesStatusPaginator,
    DescribeConfigurationAggregatorsPaginator,
    DescribeConformancePackStatusPaginator,
    DescribeConformancePacksPaginator,
    DescribeOrganizationConfigRuleStatusesPaginator,
    DescribeOrganizationConfigRulesPaginator,
    DescribeOrganizationConformancePackStatusesPaginator,
    DescribeOrganizationConformancePacksPaginator,
    DescribePendingAggregationRequestsPaginator,
    DescribeRemediationExecutionStatusPaginator,
    DescribeRetentionConfigurationsPaginator,
    GetAggregateComplianceDetailsByConfigRulePaginator,
    GetComplianceDetailsByConfigRulePaginator,
    GetComplianceDetailsByResourcePaginator,
    GetConformancePackComplianceSummaryPaginator,
    GetOrganizationConfigRuleDetailedStatusPaginator,
    GetOrganizationConformancePackDetailedStatusPaginator,
    GetResourceConfigHistoryPaginator,
    ListAggregateDiscoveredResourcesPaginator,
    ListDiscoveredResourcesPaginator,
    ListTagsForResourcePaginator,
    SelectAggregateResourceConfigPaginator,
    SelectResourceConfigPaginator,
)

session = get_session()
with async session.create_client("config") as client:
    client: ConfigServiceClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_aggregate_compliance_by_config_rules_paginator: DescribeAggregateComplianceByConfigRulesPaginator = client.get_paginator("describe_aggregate_compliance_by_config_rules")
        describe_aggregate_compliance_by_conformance_packs_paginator: DescribeAggregateComplianceByConformancePacksPaginator = client.get_paginator("describe_aggregate_compliance_by_conformance_packs")
        describe_aggregation_authorizations_paginator: DescribeAggregationAuthorizationsPaginator = client.get_paginator("describe_aggregation_authorizations")
        describe_compliance_by_config_rule_paginator: DescribeComplianceByConfigRulePaginator = client.get_paginator("describe_compliance_by_config_rule")
        describe_compliance_by_resource_paginator: DescribeComplianceByResourcePaginator = client.get_paginator("describe_compliance_by_resource")
        describe_config_rule_evaluation_status_paginator: DescribeConfigRuleEvaluationStatusPaginator = client.get_paginator("describe_config_rule_evaluation_status")
        describe_config_rules_paginator: DescribeConfigRulesPaginator = client.get_paginator("describe_config_rules")
        describe_configuration_aggregator_sources_status_paginator: DescribeConfigurationAggregatorSourcesStatusPaginator = client.get_paginator("describe_configuration_aggregator_sources_status")
        describe_configuration_aggregators_paginator: DescribeConfigurationAggregatorsPaginator = client.get_paginator("describe_configuration_aggregators")
        describe_conformance_pack_status_paginator: DescribeConformancePackStatusPaginator = client.get_paginator("describe_conformance_pack_status")
        describe_conformance_packs_paginator: DescribeConformancePacksPaginator = client.get_paginator("describe_conformance_packs")
        describe_organization_config_rule_statuses_paginator: DescribeOrganizationConfigRuleStatusesPaginator = client.get_paginator("describe_organization_config_rule_statuses")
        describe_organization_config_rules_paginator: DescribeOrganizationConfigRulesPaginator = client.get_paginator("describe_organization_config_rules")
        describe_organization_conformance_pack_statuses_paginator: DescribeOrganizationConformancePackStatusesPaginator = client.get_paginator("describe_organization_conformance_pack_statuses")
        describe_organization_conformance_packs_paginator: DescribeOrganizationConformancePacksPaginator = client.get_paginator("describe_organization_conformance_packs")
        describe_pending_aggregation_requests_paginator: DescribePendingAggregationRequestsPaginator = client.get_paginator("describe_pending_aggregation_requests")
        describe_remediation_execution_status_paginator: DescribeRemediationExecutionStatusPaginator = client.get_paginator("describe_remediation_execution_status")
        describe_retention_configurations_paginator: DescribeRetentionConfigurationsPaginator = client.get_paginator("describe_retention_configurations")
        get_aggregate_compliance_details_by_config_rule_paginator: GetAggregateComplianceDetailsByConfigRulePaginator = client.get_paginator("get_aggregate_compliance_details_by_config_rule")
        get_compliance_details_by_config_rule_paginator: GetComplianceDetailsByConfigRulePaginator = client.get_paginator("get_compliance_details_by_config_rule")
        get_compliance_details_by_resource_paginator: GetComplianceDetailsByResourcePaginator = client.get_paginator("get_compliance_details_by_resource")
        get_conformance_pack_compliance_summary_paginator: GetConformancePackComplianceSummaryPaginator = client.get_paginator("get_conformance_pack_compliance_summary")
        get_organization_config_rule_detailed_status_paginator: GetOrganizationConfigRuleDetailedStatusPaginator = client.get_paginator("get_organization_config_rule_detailed_status")
        get_organization_conformance_pack_detailed_status_paginator: GetOrganizationConformancePackDetailedStatusPaginator = client.get_paginator("get_organization_conformance_pack_detailed_status")
        get_resource_config_history_paginator: GetResourceConfigHistoryPaginator = client.get_paginator("get_resource_config_history")
        list_aggregate_discovered_resources_paginator: ListAggregateDiscoveredResourcesPaginator = client.get_paginator("list_aggregate_discovered_resources")
        list_discovered_resources_paginator: ListDiscoveredResourcesPaginator = client.get_paginator("list_discovered_resources")
        list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
        select_aggregate_resource_config_paginator: SelectAggregateResourceConfigPaginator = client.get_paginator("select_aggregate_resource_config")
        select_resource_config_paginator: SelectResourceConfigPaginator = client.get_paginator("select_resource_config")
    ```







### Literals

`types_aiobotocore_config.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_config.literals import (
    AggregateConformancePackComplianceSummaryGroupKeyType,
    AggregatedSourceStatusTypeType,
    AggregatedSourceTypeType,
    ChronologicalOrderType,
    ComplianceTypeType,
    ConfigRuleComplianceSummaryGroupKeyType,
    ConfigRuleStateType,
    ConfigurationItemStatusType,
    ConformancePackComplianceTypeType,
    ConformancePackStateType,
    DeliveryStatusType,
    DescribeAggregateComplianceByConfigRulesPaginatorName,
    DescribeAggregateComplianceByConformancePacksPaginatorName,
    DescribeAggregationAuthorizationsPaginatorName,
    DescribeComplianceByConfigRulePaginatorName,
    DescribeComplianceByResourcePaginatorName,
    DescribeConfigRuleEvaluationStatusPaginatorName,
    DescribeConfigRulesPaginatorName,
    DescribeConfigurationAggregatorSourcesStatusPaginatorName,
    DescribeConfigurationAggregatorsPaginatorName,
    DescribeConformancePackStatusPaginatorName,
    DescribeConformancePacksPaginatorName,
    DescribeOrganizationConfigRuleStatusesPaginatorName,
    DescribeOrganizationConfigRulesPaginatorName,
    DescribeOrganizationConformancePackStatusesPaginatorName,
    DescribeOrganizationConformancePacksPaginatorName,
    DescribePendingAggregationRequestsPaginatorName,
    DescribeRemediationExecutionStatusPaginatorName,
    DescribeRetentionConfigurationsPaginatorName,
    EventSourceType,
    GetAggregateComplianceDetailsByConfigRulePaginatorName,
    GetComplianceDetailsByConfigRulePaginatorName,
    GetComplianceDetailsByResourcePaginatorName,
    GetConformancePackComplianceSummaryPaginatorName,
    GetOrganizationConfigRuleDetailedStatusPaginatorName,
    GetOrganizationConformancePackDetailedStatusPaginatorName,
    GetResourceConfigHistoryPaginatorName,
    ListAggregateDiscoveredResourcesPaginatorName,
    ListDiscoveredResourcesPaginatorName,
    ListTagsForResourcePaginatorName,
    MaximumExecutionFrequencyType,
    MemberAccountRuleStatusType,
    MessageTypeType,
    OrganizationConfigRuleTriggerTypeType,
    OrganizationResourceDetailedStatusType,
    OrganizationResourceStatusType,
    OrganizationRuleStatusType,
    OwnerType,
    RecorderStatusType,
    RemediationExecutionStateType,
    RemediationExecutionStepStateType,
    RemediationTargetTypeType,
    ResourceCountGroupKeyType,
    ResourceTypeType,
    ResourceValueTypeType,
    SelectAggregateResourceConfigPaginatorName,
    SelectResourceConfigPaginatorName,
    ServiceName,
    PaginatorName,
)

def check_value(value: AggregateConformancePackComplianceSummaryGroupKeyType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_config.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_config.type_defs import (
    AccountAggregationSourceTypeDef,
    AggregateComplianceByConfigRuleTypeDef,
    AggregateComplianceByConformancePackTypeDef,
    AggregateComplianceCountTypeDef,
    AggregateConformancePackComplianceCountTypeDef,
    AggregateConformancePackComplianceFiltersTypeDef,
    AggregateConformancePackComplianceSummaryFiltersTypeDef,
    AggregateConformancePackComplianceSummaryTypeDef,
    AggregateConformancePackComplianceTypeDef,
    AggregateEvaluationResultTypeDef,
    AggregateResourceIdentifierTypeDef,
    AggregatedSourceStatusTypeDef,
    AggregationAuthorizationTypeDef,
    BaseConfigurationItemTypeDef,
    BatchGetAggregateResourceConfigRequestRequestTypeDef,
    BatchGetAggregateResourceConfigResponseTypeDef,
    BatchGetResourceConfigRequestRequestTypeDef,
    BatchGetResourceConfigResponseTypeDef,
    ComplianceByConfigRuleTypeDef,
    ComplianceByResourceTypeDef,
    ComplianceContributorCountTypeDef,
    ComplianceSummaryByResourceTypeTypeDef,
    ComplianceSummaryTypeDef,
    ComplianceTypeDef,
    ConfigExportDeliveryInfoTypeDef,
    ConfigRuleComplianceFiltersTypeDef,
    ConfigRuleComplianceSummaryFiltersTypeDef,
    ConfigRuleEvaluationStatusTypeDef,
    ConfigRuleTypeDef,
    ConfigSnapshotDeliveryPropertiesTypeDef,
    ConfigStreamDeliveryInfoTypeDef,
    ConfigurationAggregatorTypeDef,
    ConfigurationItemTypeDef,
    ConfigurationRecorderStatusTypeDef,
    ConfigurationRecorderTypeDef,
    ConformancePackComplianceFiltersTypeDef,
    ConformancePackComplianceSummaryTypeDef,
    ConformancePackDetailTypeDef,
    ConformancePackEvaluationFiltersTypeDef,
    ConformancePackEvaluationResultTypeDef,
    ConformancePackInputParameterTypeDef,
    ConformancePackRuleComplianceTypeDef,
    ConformancePackStatusDetailTypeDef,
    DeleteAggregationAuthorizationRequestRequestTypeDef,
    DeleteConfigRuleRequestRequestTypeDef,
    DeleteConfigurationAggregatorRequestRequestTypeDef,
    DeleteConfigurationRecorderRequestRequestTypeDef,
    DeleteConformancePackRequestRequestTypeDef,
    DeleteDeliveryChannelRequestRequestTypeDef,
    DeleteEvaluationResultsRequestRequestTypeDef,
    DeleteOrganizationConfigRuleRequestRequestTypeDef,
    DeleteOrganizationConformancePackRequestRequestTypeDef,
    DeletePendingAggregationRequestRequestRequestTypeDef,
    DeleteRemediationConfigurationRequestRequestTypeDef,
    DeleteRemediationExceptionsRequestRequestTypeDef,
    DeleteRemediationExceptionsResponseTypeDef,
    DeleteResourceConfigRequestRequestTypeDef,
    DeleteRetentionConfigurationRequestRequestTypeDef,
    DeleteStoredQueryRequestRequestTypeDef,
    DeliverConfigSnapshotRequestRequestTypeDef,
    DeliverConfigSnapshotResponseTypeDef,
    DeliveryChannelStatusTypeDef,
    DeliveryChannelTypeDef,
    DescribeAggregateComplianceByConfigRulesRequestRequestTypeDef,
    DescribeAggregateComplianceByConfigRulesResponseTypeDef,
    DescribeAggregateComplianceByConformancePacksRequestRequestTypeDef,
    DescribeAggregateComplianceByConformancePacksResponseTypeDef,
    DescribeAggregationAuthorizationsRequestRequestTypeDef,
    DescribeAggregationAuthorizationsResponseTypeDef,
    DescribeComplianceByConfigRuleRequestRequestTypeDef,
    DescribeComplianceByConfigRuleResponseTypeDef,
    DescribeComplianceByResourceRequestRequestTypeDef,
    DescribeComplianceByResourceResponseTypeDef,
    DescribeConfigRuleEvaluationStatusRequestRequestTypeDef,
    DescribeConfigRuleEvaluationStatusResponseTypeDef,
    DescribeConfigRulesRequestRequestTypeDef,
    DescribeConfigRulesResponseTypeDef,
    DescribeConfigurationAggregatorSourcesStatusRequestRequestTypeDef,
    DescribeConfigurationAggregatorSourcesStatusResponseTypeDef,
    DescribeConfigurationAggregatorsRequestRequestTypeDef,
    DescribeConfigurationAggregatorsResponseTypeDef,
    DescribeConfigurationRecorderStatusRequestRequestTypeDef,
    DescribeConfigurationRecorderStatusResponseTypeDef,
    DescribeConfigurationRecordersRequestRequestTypeDef,
    DescribeConfigurationRecordersResponseTypeDef,
    DescribeConformancePackComplianceRequestRequestTypeDef,
    DescribeConformancePackComplianceResponseTypeDef,
    DescribeConformancePackStatusRequestRequestTypeDef,
    DescribeConformancePackStatusResponseTypeDef,
    DescribeConformancePacksRequestRequestTypeDef,
    DescribeConformancePacksResponseTypeDef,
    DescribeDeliveryChannelStatusRequestRequestTypeDef,
    DescribeDeliveryChannelStatusResponseTypeDef,
    DescribeDeliveryChannelsRequestRequestTypeDef,
    DescribeDeliveryChannelsResponseTypeDef,
    DescribeOrganizationConfigRuleStatusesRequestRequestTypeDef,
    DescribeOrganizationConfigRuleStatusesResponseTypeDef,
    DescribeOrganizationConfigRulesRequestRequestTypeDef,
    DescribeOrganizationConfigRulesResponseTypeDef,
    DescribeOrganizationConformancePackStatusesRequestRequestTypeDef,
    DescribeOrganizationConformancePackStatusesResponseTypeDef,
    DescribeOrganizationConformancePacksRequestRequestTypeDef,
    DescribeOrganizationConformancePacksResponseTypeDef,
    DescribePendingAggregationRequestsRequestRequestTypeDef,
    DescribePendingAggregationRequestsResponseTypeDef,
    DescribeRemediationConfigurationsRequestRequestTypeDef,
    DescribeRemediationConfigurationsResponseTypeDef,
    DescribeRemediationExceptionsRequestRequestTypeDef,
    DescribeRemediationExceptionsResponseTypeDef,
    DescribeRemediationExecutionStatusRequestRequestTypeDef,
    DescribeRemediationExecutionStatusResponseTypeDef,
    DescribeRetentionConfigurationsRequestRequestTypeDef,
    DescribeRetentionConfigurationsResponseTypeDef,
    EvaluationResultIdentifierTypeDef,
    EvaluationResultQualifierTypeDef,
    EvaluationResultTypeDef,
    EvaluationTypeDef,
    ExecutionControlsTypeDef,
    ExternalEvaluationTypeDef,
    FailedDeleteRemediationExceptionsBatchTypeDef,
    FailedRemediationBatchTypeDef,
    FailedRemediationExceptionBatchTypeDef,
    FieldInfoTypeDef,
    GetAggregateComplianceDetailsByConfigRuleRequestRequestTypeDef,
    GetAggregateComplianceDetailsByConfigRuleResponseTypeDef,
    GetAggregateConfigRuleComplianceSummaryRequestRequestTypeDef,
    GetAggregateConfigRuleComplianceSummaryResponseTypeDef,
    GetAggregateConformancePackComplianceSummaryRequestRequestTypeDef,
    GetAggregateConformancePackComplianceSummaryResponseTypeDef,
    GetAggregateDiscoveredResourceCountsRequestRequestTypeDef,
    GetAggregateDiscoveredResourceCountsResponseTypeDef,
    GetAggregateResourceConfigRequestRequestTypeDef,
    GetAggregateResourceConfigResponseTypeDef,
    GetComplianceDetailsByConfigRuleRequestRequestTypeDef,
    GetComplianceDetailsByConfigRuleResponseTypeDef,
    GetComplianceDetailsByResourceRequestRequestTypeDef,
    GetComplianceDetailsByResourceResponseTypeDef,
    GetComplianceSummaryByConfigRuleResponseTypeDef,
    GetComplianceSummaryByResourceTypeRequestRequestTypeDef,
    GetComplianceSummaryByResourceTypeResponseTypeDef,
    GetConformancePackComplianceDetailsRequestRequestTypeDef,
    GetConformancePackComplianceDetailsResponseTypeDef,
    GetConformancePackComplianceSummaryRequestRequestTypeDef,
    GetConformancePackComplianceSummaryResponseTypeDef,
    GetDiscoveredResourceCountsRequestRequestTypeDef,
    GetDiscoveredResourceCountsResponseTypeDef,
    GetOrganizationConfigRuleDetailedStatusRequestRequestTypeDef,
    GetOrganizationConfigRuleDetailedStatusResponseTypeDef,
    GetOrganizationConformancePackDetailedStatusRequestRequestTypeDef,
    GetOrganizationConformancePackDetailedStatusResponseTypeDef,
    GetResourceConfigHistoryRequestRequestTypeDef,
    GetResourceConfigHistoryResponseTypeDef,
    GetStoredQueryRequestRequestTypeDef,
    GetStoredQueryResponseTypeDef,
    GroupedResourceCountTypeDef,
    ListAggregateDiscoveredResourcesRequestRequestTypeDef,
    ListAggregateDiscoveredResourcesResponseTypeDef,
    ListDiscoveredResourcesRequestRequestTypeDef,
    ListDiscoveredResourcesResponseTypeDef,
    ListStoredQueriesRequestRequestTypeDef,
    ListStoredQueriesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    MemberAccountStatusTypeDef,
    OrganizationAggregationSourceTypeDef,
    OrganizationConfigRuleStatusTypeDef,
    OrganizationConfigRuleTypeDef,
    OrganizationConformancePackDetailedStatusTypeDef,
    OrganizationConformancePackStatusTypeDef,
    OrganizationConformancePackTypeDef,
    OrganizationCustomRuleMetadataTypeDef,
    OrganizationManagedRuleMetadataTypeDef,
    OrganizationResourceDetailedStatusFiltersTypeDef,
    PaginatorConfigTypeDef,
    PendingAggregationRequestTypeDef,
    PutAggregationAuthorizationRequestRequestTypeDef,
    PutAggregationAuthorizationResponseTypeDef,
    PutConfigRuleRequestRequestTypeDef,
    PutConfigurationAggregatorRequestRequestTypeDef,
    PutConfigurationAggregatorResponseTypeDef,
    PutConfigurationRecorderRequestRequestTypeDef,
    PutConformancePackRequestRequestTypeDef,
    PutConformancePackResponseTypeDef,
    PutDeliveryChannelRequestRequestTypeDef,
    PutEvaluationsRequestRequestTypeDef,
    PutEvaluationsResponseTypeDef,
    PutExternalEvaluationRequestRequestTypeDef,
    PutOrganizationConfigRuleRequestRequestTypeDef,
    PutOrganizationConfigRuleResponseTypeDef,
    PutOrganizationConformancePackRequestRequestTypeDef,
    PutOrganizationConformancePackResponseTypeDef,
    PutRemediationConfigurationsRequestRequestTypeDef,
    PutRemediationConfigurationsResponseTypeDef,
    PutRemediationExceptionsRequestRequestTypeDef,
    PutRemediationExceptionsResponseTypeDef,
    PutResourceConfigRequestRequestTypeDef,
    PutRetentionConfigurationRequestRequestTypeDef,
    PutRetentionConfigurationResponseTypeDef,
    PutStoredQueryRequestRequestTypeDef,
    PutStoredQueryResponseTypeDef,
    QueryInfoTypeDef,
    RecordingGroupTypeDef,
    RelationshipTypeDef,
    RemediationConfigurationTypeDef,
    RemediationExceptionResourceKeyTypeDef,
    RemediationExceptionTypeDef,
    RemediationExecutionStatusTypeDef,
    RemediationExecutionStepTypeDef,
    RemediationParameterValueTypeDef,
    ResourceCountFiltersTypeDef,
    ResourceCountTypeDef,
    ResourceFiltersTypeDef,
    ResourceIdentifierTypeDef,
    ResourceKeyTypeDef,
    ResourceValueTypeDef,
    ResponseMetadataTypeDef,
    RetentionConfigurationTypeDef,
    ScopeTypeDef,
    SelectAggregateResourceConfigRequestRequestTypeDef,
    SelectAggregateResourceConfigResponseTypeDef,
    SelectResourceConfigRequestRequestTypeDef,
    SelectResourceConfigResponseTypeDef,
    SourceDetailTypeDef,
    SourceTypeDef,
    SsmControlsTypeDef,
    StartConfigRulesEvaluationRequestRequestTypeDef,
    StartConfigurationRecorderRequestRequestTypeDef,
    StartRemediationExecutionRequestRequestTypeDef,
    StartRemediationExecutionResponseTypeDef,
    StaticValueTypeDef,
    StatusDetailFiltersTypeDef,
    StopConfigurationRecorderRequestRequestTypeDef,
    StoredQueryMetadataTypeDef,
    StoredQueryTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
)

def get_structure() -> AccountAggregationSourceTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-config` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-config docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_config/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
